import request from '@/utils/request'

export function getdgtIndustryNews(query) {
  return request({
    url: '/news/getdgtIndustryNews',
    method: 'post',
    data: query
  })
}

export function listNews(query) {
  return request({
    url: '/news/listForDGTSiteNews',
    method: 'post',
    data: query
  })
}

export function createNews(data) {
  return request({
    url: '/news/createForDGTSiteNews',
    method: 'post',
    data
  })
}

export function updateNews(data) {
  return request({
    url: '/news/update',
    method: 'post',
    data
  })
}

export function deleteNews(data) {
  return request({
    url: '/news/delete',
    method: 'post',
    data
  })
}

export function deleteAllNews(data) {
  return request({
    url: '/news/deleteQuantity',
    method: 'post',
    params: data
  })
}
